@@ -5,4 +5,5 @@ use cursor::Cursor;
 mod token;
 pub(crate) use token::{Token, TokenKind, CommentKind};
 mod parser;
-pub(crate) use parser::{Parser, ParseError};
+pub(crate) use parser::Parser;
+pub use parser::ParseError;
